===========
heka-py-cef
===========

.. image:: https://secure.travis-ci.org/mozilla-services/heka-py-cef.png

heka-py-cef is a plugin extension for `heka-py 
<http://github.com/mozilla-services/heka-py>`_.  heka-py-cef
provides an extension to log send CEF messages to a heka server.

More information about how Mozilla Services is using heka (including what is
being used for a router and what endpoints are in use / planning to be used)
can be found on the `Read The Docs page 
<https://heka-docs.readthedocs.org>`_.
